pub fn db_name_of_test_pool(
connect_opts: &PgConnectOptions,
) -> Result<String, Error>Expand description
Returns the name of the database for the test pool or error
pub fn db_name_of_test_pool(
connect_opts: &PgConnectOptions,
) -> Result<String, Error>Returns the name of the database for the test pool or error